from .setup import setup_observability
from .config import ObservabilityConfig
from .integrations import setup_django, setup_fastapi, setup_celery
from .metrics import (
    get_meter,
    get_request_counter,
    get_request_duration_histogram,
    get_active_connections_counter,
)

__version__ = "1.0.37"
__all__ = [
    "setup_observability",
    "ObservabilityConfig",
    "setup_django",
    "setup_fastapi",
    "setup_celery",
    "get_meter",
    "get_request_counter",
    "get_request_duration_histogram",
    "get_active_connections_counter",
]
